Samplea factor with the sample type
Typea factor with the following levels: HD (Heavy Diesel), LD (Light Diesel), LGO (Light Gas Oil), MGO (Medium Gas Oil).
HPLCmonoa numeric vector with the monoaromatics measurements by HPLC.
GCMSmonoa numeric vector with the monoaromatics measurements by GC MS.
HPLCdia numeric vector with the diaromatics measurements by HPLC.
GCMSdia numeric vector with the diaromatics measurements by GC MS.
HPLCtria numeric vector with the triaromatics measurements by HPLC.
GCMStria numeric vector with the triaromatics measurements by GC MS.